<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Klien Jabber/XMPP yang mudah, mesra pengguna</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Lesen:</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Lihat kod sumber dalam talian</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Laporkan masalah</translation>
    </message>
</context>
<context>
    <name>AboutPage</name>
    <message>
        <source>About</source>
        <translation type="vanished">Latar Belakang</translation>
    </message>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">Klien Jabber/XMPP yang mudah, mesra pengguna</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">Lesen:</translation>
    </message>
    <message>
        <source>Sourcecode on GitHub</source>
        <translation type="vanished">Kod sumber di GitHub</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Tutup</translation>
    </message>
</context>
<context>
    <name>AboutSheet</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="obsolete">Klien Jabber/XMPP yang mudah, mesra pengguna</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="obsolete">Lesen:</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
    <message>
        <source>Delete account completely</source>
        <translation type="vanished">Padam keseluruhan akaun</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="vanished">Akaun anda akan dipadam keseluruhannya, iaitu dipadam daripada aplikasi ini dan juga daripada pelayan.
Anda tidak akan mampu menggunakan akaun anda lagi!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Padam</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientConfirmationPage</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="vanished">Buang akaun daripada aplikasi ini</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
You won&apos;t be able to get your credentials back!
Make sure that you have backed up those if you want to use your account later.</source>
        <translation type="vanished">Akaun anda akan dibuang daripada aplikasi ini.
Anda tidak akan mampu mendapatkan kelayakan anda semula!
Sila pastikan anda telah menyandarkan kelayakan sekiranya anda ingin menggunakan akaun anda pada waktu akan datang.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Buang</translation>
    </message>
</context>
<context>
    <name>AccountDeletionPage</name>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Padam akaun</translation>
    </message>
    <message>
        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
        <translation type="vanished">Anda boleh membuang akaun anda &lt;b&gt;%1&lt;/b&gt; hanya daripada aplikasi ini atau memadamnya secara keseluruhannya. Jika anda memadam akaun anda keseluruhannya, anda tidak akan mampu menggunakan akaun tersebut di aplikasi lain kerana ia turut dibuang daripada pelayan.</translation>
    </message>
    <message>
        <source>Remove from this app</source>
        <translation type="vanished">Buang daripada aplikasi ini</translation>
    </message>
    <message>
        <source>Delete completely</source>
        <translation type="vanished">Padam keseluruhannya</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>Keselamatan Akaun</translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation type="vanished">Membolehkan penambahan peranti baharu menggunakan Kod QR, tetapi tidak menunjukkan kata laluan sebagai teks. Perbuatan ini tidak boleh diundur, jadi anda disyorkan untuk menyimpan kata laluan dalam cara yang lain sebelum menggunakannya.</translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation type="vanished">Lumpuhkan penampakan kata laluan</translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation type="vanished">Jangan dedah kata laluan dengan sebarang cara. Perbuatan ini tidak boleh diundur.</translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation type="vanished">Lumpuhkan penampakan Kod QR dan kata laluan</translation>
    </message>
    <message>
        <source>Allow to add additional devices using the login QR code but never show the password.</source>
        <translation>Benarkan penambahan peranti tambahan menggunakan kod QR log masuk tetapi jangan tunjukkan kata laluan.</translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation>Jangan tunjukkan kata laluan</translation>
    </message>
    <message>
        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
        <translation>Jangan benarkan penambahan peranti tambahan menggunakan kod QR log masuk dan jangan tunjukkan kata laluan.</translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation>Jangan dedahkan kata laluan dalam sebarang cara</translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Pindahkan akaun ke peranti lain</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Imbas kod QR atau masukkan kelayakan sebagai teks di peranti lain untuk log masuk ke akaun.

Perhatian:
Jangan sesekali tunjukkan kod QR ini kepada orang lain. Ia akan membenarkan capaian tanpa had ke akaun anda!</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>Alamat sembang:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Kata laluan:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>Sembunyi kod QR</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Tunjuk sebagai kod QR</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Sembunyi teks</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Tunjuk sebagai teks</translation>
    </message>
    <message>
        <source>Copy JID</source>
        <translation type="vanished">Salin JID</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Salin kata laluan</translation>
    </message>
    <message>
        <source>Copy chat address</source>
        <translation>Salin alamat sembang</translation>
    </message>
</context>
<context>
    <name>BackButton</name>
    <message>
        <source>Navigate Back</source>
        <translation type="vanished">Ke Belakang</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Tukar kata laluan</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Kata laluan semasa:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Kata laluan baru:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Kata laluan baru (ulang semula):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>Kata laluan baru yang diulang tidak sepadan.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>Kata laluan semasa tidak sah.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="vanished">Anda mesti sambung ke internet untuk menukar kata laluan anda.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Selepas anda menukar kata laluan, anda perlu log masuk semula di kesemua peranti anda yang lain.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Tukar</translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation>Kata laluan berjaya ditukar</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>Gagal menukar kata laluan: %1</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Message copied to clipboard</source>
        <translation type="vanished">Mesej disalin ke papan klip</translation>
    </message>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Salin Mesej</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Sunting Mesej</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Beberan</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Muat Turun</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Salin URL muat turun</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>Salin mesej</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>Sunting mesej</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation>Salin URL muat turun</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation>Petik mesej</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation type="vanished">Tulis mesej</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="vanished">Hantar</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Imej</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Dokumen</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Fail lain</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Pilih fail</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Hantar mesej beberan</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation type="vanished">Tip beberan</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Buang bisu pemberitahuan</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Bisukan pemberitahuan</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Lihat profil</translation>
    </message>
    <message>
        <source>Multimedia settings</source>
        <translation type="vanished">Tetapan multimedia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cari</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Tutup</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Cari atas</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Cari bawah</translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="vanished">Semua fail</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation type="vanished">Salin mesej</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="vanished">Sunting mesej</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Salin URL muat turun</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="vanished">Petik mesej</translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation>Tutup bar gelintar mesej</translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation>Tip beberan</translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation>Tutup medan tip beberan</translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation>Karang mesej</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation>Akaun anda tidak boleh dipadam daripada pelayan. Oleh itu, ia juga tidak dibuang daripada aplikasi ini: %1</translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Sangat rendah</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Rendah</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Biasa</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Tinggi</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Sangat tinggi</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Kualiti malar</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Kadar bit malar</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Kadar bit purata</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Dua tapis</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation>Tetapan sambungan</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Tukar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation>Tetapan sambungan tidak dapat ditukar</translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation>Tetapan sambungan ditukar</translation>
    </message>
</context>
<context>
    <name>ContextDrawer</name>
    <message>
        <source>Actions</source>
        <translation type="vanished">Tindakan</translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation>Nama hos:</translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation>Nama hos tidak boleh mengandungi ruang kosong</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation type="vanished">Buang kata laluan sepenuhnya</translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="vanished">Kata laluan anda sudah tidak akan disertakan dalam kod QR.
Anda tidak akan mampu log masuk menerusi kod QR tanpa memasukkan kata laluan anda lagi kerana perbuatan ini tidak boleh diundur!
Pastikan anda sandarkannya jika anda ingin gunakan akaun anda kemudian.</translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation type="vanished">Buang kata laluan</translation>
    </message>
    <message>
        <source>Don&apos;t expose your password in any way</source>
        <translation>Jangan dedahkan kata laluan anda dalam sebarang cara</translation>
    </message>
    <message>
        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device.</source>
        <translation>Kata laluan anda tidak akan ditunjukkan sebagai teks biasa dan tidak akan disertakan dalam kod QR log masuk.
Anda tidak mampu menggunakan log masuk melalui kod QR tanpa memasukkan kata laluan anda lagi kerana tindakan ini tidak boleh diundurkan!
Pertimbangkan untuk menyimpan kata laluan di tempat lain sekiranya anda ingin gunakan akaun anda di peranti lain.</translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation>Jangan dedahkan kata laluan dalam sebarang cara</translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation type="vanished">Jangan tunjukkan kata laluan sebagai teks</translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="vanished">Kata laluan anda sudah tidak akan ditunjukkan sebagai teks.
Anda tidak akan mampu melihat kata laluan anda sebagai teks lagi kerana perbuatan ini tidak boleh diundur!
Pastikan anda sandarkannya jika anda ingin gunakan akaun anda kemudian.</translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation type="vanished">Jangan tunjuk kata laluan</translation>
    </message>
    <message>
        <source>Don&apos;t show your password</source>
        <translation>Jangan tunjukkan kata laluan anda</translation>
    </message>
    <message>
        <source>Your password will not be shown anymore but still exposed via the login QR code.
You won&apos;t be able to see your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
        <translation>Kata laluan anda tidak akan ditunjukkan lagi tetapi masih didedahkan melalui kod QR log masuk.
Anda tidak mampu melihat kata laluan anda lagi kerana tindakan ini tidak boleh diundurkan!
Pertimbangkan untuk menyimpan kata laluan di tempat lain sekiranya anda ingin gunakan akaun anda di peranti lain tanpa kod QR log masuk.</translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation>Jangan tunjukkan kata laluan</translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>Tidak dapat menyimpan fail: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Muat turun gagal: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="vanished">Kegemaran</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="vanished">Manusia</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="vanished">Alam</translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="vanished">Makanan</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="vanished">Aktiviti</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">Perlancongan</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="vanished">Objek</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="vanished">Simbol</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="vanished">Bendera</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Cari</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="vanished">Cari emoji</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Sila pilih seseorang untuk mula menghantar mesej</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Pilih fail</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>Close</source>
        <translation type="vanished">Tutup</translation>
    </message>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">Naik ke folder atas</translation>
    </message>
</context>
<context>
    <name>ForwardButton</name>
    <message>
        <source>Navigate Forward</source>
        <translation type="vanished">Ke Depan</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Log out</source>
        <translation type="vanished">Log keluar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Latar Belakang</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation type="vanished">Tambah kenalan baru</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">Kembali</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Undang kawan</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Pautan undangan telah disalin ke papan klip</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Luar talian</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dalam talian</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Menyambung…</translation>
    </message>
    <message>
        <source>Transfer account</source>
        <translation type="vanished">Pindah akaun</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Padam akaun</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation>Tukar peranti</translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Tidak dapat hantar mesej, kerana anda tiada sambungan internet.</translation>
    </message>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="vanished">Tidak dapat menambah kenalan, kerana anda tiada sambungan internet.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="vanished">Tidak dapat membuang kenalan, kerana anda tiada sambungan internet.</translation>
    </message>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>Pautan akan dibuka selepas anda disambungkan.</translation>
    </message>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="vanished">Tidak dapat menghantar fail, kerana anda tidak disambung ke internet.</translation>
    </message>
    <message>
        <source>No password found. Please enter it.</source>
        <translation type="vanished">Tiada kata laluan dijumpai. Sila masukkan kata laluan anda.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation type="vanished">Tiada kod QR log masuk yang sah dijumpai.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation>Buang akaun daripada aplikasi ini</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation>Akaun anda akan dibuang daripada aplikasi ini.
Kata laluan anda akan dipadam, pastikan ia disimpan dalam pengurus kata laluan anda atau pastikan anda mengetahui kata laluan anda!</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Buang</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">Jabber-ID anda：</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">contoh＠emel.com</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Kata Laluan Anda：</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Kata Laluan</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="vanished">Cuba Lagi</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Sambung</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Menyambung…</translation>
    </message>
    <message>
        <source>Log in</source>
        <translation>Log masuk</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Log masuk akaun XMPP anda</translation>
    </message>
    <message>
        <source>Your diaspora*-ID:</source>
        <translation type="vanished">ID diaspora* anda:</translation>
    </message>
    <message>
        <source>user@diaspora.pod</source>
        <translation type="vanished">nama@diaspora.pod</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Nama pengguna atau kata laluan tidak sah.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">Tidak dapat menghubungi pelayan. Sila periksa sambungan internet anda.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">Pelayan tidak menyokong sambungan selamat.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Ralat ketika cuba untuk menyambung secara selamat.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">Tidak dapat menetapkan alamat pelayan. Sila periksa semula JID anda.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Tidak dapat menghubungi pelayan.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Protokol pengesahan tidak disokong oleh pelayan.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">Telah berlaku ralat tidak diketahui; lihat log untuk maklumat lanjut.</translation>
    </message>
    <message>
        <source>Log in using a QR-Code</source>
        <translation type="vanished">Log masuk menggunakan kod QR</translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation>Tetapan sambungan</translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation>Tetapan sambungan</translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation>Tetapan sambungan akan disimpan secara kekal selepas log masuk pertama yang berjaya. Jika ia tidak berjaya, anda akan kembali ke halaman log masuk.</translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation>Bolehkan tetapan sambungan tersuai</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation>Nama hos:</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Tetap semula</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Gunakan</translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Asal</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Ambil gambar</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Rakam video</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Rakam suara</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Hantar kedudukan</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Pilih fail</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Pilih imej</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Pilih video</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Pilih fail audio</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Pilih dokumen</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Semua fail</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imej</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Fail audio</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumen</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Dokumen</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lokasi</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Imej</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fail</translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation>Beberan</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Tidak dapat hantar mesej, kerana anda tiada sambungan internet.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">Tidak dapat membetulkan mesej, kerana anda tidak sambung ke internet.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Beberan</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Mesej gagal dihantar.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>Pembetulan mesej tidak berjaya.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation>Menghantar</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Dihantar</translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation>Diterima</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>Tetapan Multimedia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Tetapkan</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>Tangkapan Imej</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>Rakaman Audio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>Rakaman Video</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>Kemasukan audio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>Bekas</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Imej</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolusi</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kualiti</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Kadar Sampel</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>Kadar Bingkai</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Sedia</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Mengasalkan…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Tidak tersedia</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>Merakam…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Dijedakan</translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="vanished">Tetapan Multimedia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="vanished">Tetapkan</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="vanished">Tangkapan Imej</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="vanished">Rakaman Audio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="vanished">Rakaman Video</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="vanished">Kamera</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="vanished">Kemasukan audio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="vanished">Bekas</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Imej</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="vanished">Kodek</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="vanished">Resolusi</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="vanished">Kualiti</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="vanished">Kadar Sampel</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="vanished">Kadar Bingkai</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="vanished">Sedia</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="vanished">Mengasalkan…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="vanished">Tidak tersedia</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="vanished">Merakam…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="vanished">Dijedakan</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation type="vanished">Sedia</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Mengasalkan…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Tidak tersedia</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>Merakam… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>Dijedakan %1</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation>Buang kata laluan</translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation>Anda boleh pilih sama ada anda hanya ingin kata laluan anda tidak ditunjukkan sebagai teks lagi untuk &lt;b&gt;%1&lt;/b&gt; ataupun anda ingin membuang kata laluan sepenuhnya daripada pindahan akaun. Jika anda membuang kata laluan sepenuhnya, anda tidak akan mampu menggunakan fungsi pindahan akaun secara imbasan tanpa memasukkan kata laluan anda kerana kata laluan akan turut dibuang daripada kod QR.</translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation>Jangan tunjuk kata laluan sebagai teks</translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation>Buang sepenuhnya</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation>Tanda sebagai telah dibaca</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Lapang</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation>Boleh sembang</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Tidak lapang</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation>Jangan ganggu</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation>Tidak lapang lebih lama</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Luar talian</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation type="vanished">Tersedia</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Lapang untuk sembang</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Tidak lapang</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Jangan ganggu</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Tidak lapang lebih lama</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Luar talian</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Ralat</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="vanished">Tidak kelihatan</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation>Nama pengguna atau kata laluan tidak sah.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>Tidak dapat menghubungi pelayan. Sila periksa sambungan internet anda.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>Pelayan tidak menyokong sambungan selamat.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>Ralat ketika cuba untuk menyambung secara selamat.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation type="vanished">Tidak dapat menyelesaikan alamat pelayan. Sila periksa nama pelayan anda.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">Tidak dapat menghubungi pelayan.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>Protokol pengesahan tidak disokong oleh pelayan.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation>Pelayan ini tidak menyokong pendaftaran.</translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation>Pelayan berada di luar talian atau disekat tembok api.</translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation>Sambungan tidak dapat disegarkan semula.</translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation>Capaian internet tidak dibenarkan. Sila periksa tatarajah capaian internet sistem anda.</translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation>Tidak boleh sambung ke pelayan. Sila periksa sambungan internet anda atau nama pelayan anda.</translation>
    </message>
    <message>
        <source>%1 is online</source>
        <translation>%1 berada dalam talian</translation>
    </message>
    <message>
        <source>%1 is typing…</source>
        <translation>%1 sedang menaip…</translation>
    </message>
    <message>
        <source>%1 paused typing</source>
        <translation>%1 berhenti menaip</translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation>Penjanaan kod QR telah gagal: %1</translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation>Imbas kod QR</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation>Tunjukkan penjelasan</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation>Teruskan tanpa kod QR</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation>Imbas kod QR dari peranti anda yang sedia ada untuk memindahkan akaun anda.</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Menyambung…</translation>
    </message>
    <message>
        <source>This QR code is not a valid login QR code.</source>
        <translation>Kod QR ini bukannya kod QR log masuk yang sah.</translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation>Format kamera &apos;%1&apos; tidak disokong.</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation>Tiada kamera tersedia.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation>Kamera anda sibuk.
Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="vanished">Imbas kod QR</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="vanished">Tiada kamera tersedia.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="vanished">Kamera anda sibuk.
Cuba tutup aplikasi lain yang menggunakan kamera.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="vanished">Format kamera &apos;%1&apos; tidak disokong.</translation>
    </message>
    <message>
        <source>Logging in…</source>
        <translation type="vanished">Sedang log masuk…</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="vanished">Imbas kod QR daripada peranti anda yang sedia ada untuk memindahkan akaun anda.</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="vanished">Tunjukkan penjelasan</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation type="vanished">Imbas</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="vanished">Teruskan tanpa kod QR</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="vanished">Menyambung…</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation>Persediakan</translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation>Daftar akaun baharu</translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation>Guna akaun sedia ada</translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation type="vanished">Kata laluan berjaya ditukar.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="vanished">Gagal menukar kata laluan: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation>Padam akaun keseluruhannya</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation>Akaun anda akan dipadam keseluruhannya, iaitu dipadam daripada aplikasi ini dan juga daripada pelayan.
Anda tidak akan mampu menggunakan akaun anda lagi!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Nickname:</source>
        <translation>Nama panggilan:</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>ID Jabber:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>contohemel@example.org</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Tambah kenalan baru</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Ini juga akan menghantar permintaan untuk mencapai kehadiran kenalan.</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Mesej pilihan:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Beritahu pasangan sembang siapakah diri anda sebenarnya.</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation type="vanished">Ralat: Sila periksa JID.</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="vanished">Sedang lapang</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Boleh sembang</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Tidak lapang</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Jangan ganggu</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Tidak lapang lebih lama</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Tiada dalam talian</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Ralat</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation type="vanished">Tidak sah</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>Tidak dapat menambah kenalan, kerana anda tiada sambungan internet.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>Tidak dapat membuang kenalan, kerana anda tiada sambungan internet.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Beberan</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>Tidak boleh menamakan semula kenalan, kerana anda tidak bersambung ke internet.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Contacts</source>
        <translation>Kenalan</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Tambah kenalan baru</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Menyambung…</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Luar talian</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Cari kenalan</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &quot;%1&quot; from your roster?</source>
        <translation type="vanished">Adakah anda ingin memadam kenalan &quot;%1&quot; daripada roster anda?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Padam kenalan</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation type="vanished">Adakah anda ingin memadam kenalan &lt;b&gt;%1&lt;/b&gt; daripada senarai anda?</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation>Adakah anda pasti anda ingin padam kenalan &lt;b&gt;%1&lt;/b&gt; dari senarai kenalan anda?</translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Namakan semula kenalan</translation>
    </message>
    <message>
        <source>Edit name:</source>
        <translation type="vanished">Sunting nama:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Namakan semula</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Hantar</translation>
    </message>
    <message>
        <source>Caption</source>
        <translation>Kapsyen</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation>Pelayan tersuai</translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation>Tiada had</translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation>%1 hari</translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation>Tukar kata laluan</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation>Tukar kata laluan akaun anda. Anda perlu masukkan ia semula di kesemua peranti anda yang lain.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation>Tetapan Multimedia</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation>Menatarajah tetapan rakaman gambar, video dan audio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation>Keselamatan akaun</translation>
    </message>
    <message>
        <source>configure whether this device can be used to log in on a new device</source>
        <translation type="vanished">tetapkan sama ada peranti ini boleh digunakan untuk log masuk peranti baharu</translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation>Buang akaun daripada Kaidan</translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation>Buang akaun daripada aplikasi ini</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Padam akaun</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation>Padam akaun daripada pelayan</translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation>Tetapan Sambungan</translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation>Tetapkan nama hos dan port untuk disambung</translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on a new device</source>
        <translation type="vanished">Tetapkan sama ada peranti ini boleh digunakan untuk log masuk di peranti baharu</translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on another device</source>
        <translation>Tetapkan sama ada peranti ini boleh digunakan untuk log masuk di peranti yang lain</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="vanished">Tukar kata laluan</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="vanished">Tukar kata laluan akaun anda. Anda perlu log masuk semula di kesemua peranti anda yang lain.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="obsolete">Tetapan Multimedia</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">Tetapan</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation>Nikmati perhubungan percuma di setiap peranti!</translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation>Mari mulakan</translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Permintaan Langganan</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Anda mendapat permintaan langganan daripada &lt;b&gt;%1&lt;/b&gt;. Jika anda terima, akaun tersebut boleh mencapai status kehadiran anda.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Tolak</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Terima</translation>
    </message>
</context>
<context>
    <name>ToolBarApplicationHeader</name>
    <message>
        <source>More Actions</source>
        <translation type="vanished">Tindakan Lanjut</translation>
    </message>
</context>
<context>
    <name>ToolBarPageHeader</name>
    <message>
        <source>More Actions</source>
        <translation type="obsolete">Tindakan Lanjut</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>Tidak dapat menghantar fail, kerana anda tidak disambung ke internet.</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Fail</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Mesej tidak dapat dihantar.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Namakan semula kenalan</translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation>Tunjuk kod QR</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Buang kenalan</translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation>Peranti dalam talian</translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nama panggilan</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Perihalan</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Emel</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Hari lahir</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Laman web</translation>
    </message>
</context>
</TS>
